@@ -178,6 +178,10 @@ class Grilo(GObject.GObject):
     def populate_songs(self, offset, callback, count=-1):
         self.populate_items(Query.all_songs(), offset, callback, count)
 
+    @log
+    def populate_playlists(self, offset, callback, count=-1):
+        self.populate_items(Query.all_playlists(), offset, callback, count)
+
     @log
     def populate_album_songs(self, album, callback, count=-1):
         if album.get_source() == 'grl-tracker-source':
@@ -189,6 +193,10 @@ class Grilo(GObject.GObject):
                 callback(source, None, track, length - (i + 1), None)
             callback(source, None, None, 0, None)
 
+    @log
+    def populate_playlist_songs(self, playlist, callback, count=-1):
+        self.populate_items(Query.playlist_songs(playlist.get_id()), 0, callback, count)
+
     @log
     def populate_custom_query(self, query, callback, count=-1, data=None):
         self.populate_items(query, 0, callback, count, data)
@@ -223,18 +231,6 @@ class Grilo(GObject.GObject):
                                 q, self.METADATA_KEYS, options,
                                 _search_callback, data)
 
-    @log
-    def get_media_from_uri(self, uri, callback):
-        options = self.options.copy()
-        query = Query.get_song_with_url(uri)
-
-        def _callback(source, param, item, count, data, error):
-            if not error:
-                callback(source, param, item)
-                return
-
-        self.tracker.query(query, self.METADATA_KEYS, options, _callback, None)
-
     @log
     def get_album_art_for_item(self, item, callback, data=None):
         item_id = item.get_id()
@@ -250,6 +246,20 @@ class Grilo(GObject.GObject):
 
         self.search_source.query(query, self.METADATA_THUMBNAIL_KEYS, options, callback, data)
 
+    @log
+    def get_playlist_with_id(self, playlist_id, callback):
+        options = self.options.copy()
+        query = Query.get_playlist_with_id(playlist_id)
+
+        self.tracker.query(query, self.METADATA_KEYS, options, callback, None)
+
+    @log
+    def get_playlist_song_with_id(self, playlist_id, entry_id, callback):
+        options = self.options.copy()
+        query = Query.get_playlist_song_with_id(playlist_id, entry_id)
+
+        self.tracker.query(query, self.METADATA_KEYS, options, callback, None)
+
 
 Grl.init(None)
 
